/****************************************************************************
** Meta object code from reading C++ file 'window_manager_interface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../window_manager_interface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'window_manager_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PlasmaWindowManagerInterface_t {
    QByteArrayData data[19];
    char stringdata0[307];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PlasmaWindowManagerInterface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PlasmaWindowManagerInterface_t qt_meta_stringdata_PlasmaWindowManagerInterface = {
    {
QT_MOC_LITERAL(0, 0, 28), // "PlasmaWindowManagerInterface"
QT_MOC_LITERAL(1, 29, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 45, 38), // "org.deepin.dde.KWayland1.Wind..."
QT_MOC_LITERAL(3, 84, 26), // "InterfaceAboutToBeReleased"
QT_MOC_LITERAL(4, 111, 0), // ""
QT_MOC_LITERAL(5, 112, 27), // "InterfaceAboutToBeDestroyed"
QT_MOC_LITERAL(6, 140, 21), // "ShowingDesktopChanged"
QT_MOC_LITERAL(7, 162, 13), // "WindowCreated"
QT_MOC_LITERAL(8, 176, 4), // "dbus"
QT_MOC_LITERAL(9, 181, 12), // "WindowRemove"
QT_MOC_LITERAL(10, 194, 19), // "ActiveWindowChanged"
QT_MOC_LITERAL(11, 214, 7), // "IsValid"
QT_MOC_LITERAL(12, 222, 16), // "IsShowingDesktop"
QT_MOC_LITERAL(13, 239, 17), // "SetShowingDesktop"
QT_MOC_LITERAL(14, 257, 4), // "show"
QT_MOC_LITERAL(15, 262, 11), // "ShowDesktop"
QT_MOC_LITERAL(16, 274, 11), // "HideDesktop"
QT_MOC_LITERAL(17, 286, 7), // "Windows"
QT_MOC_LITERAL(18, 294, 12) // "ActiveWindow"

    },
    "PlasmaWindowManagerInterface\0"
    "D-Bus Interface\0org.deepin.dde.KWayland1.WindowManager\0"
    "InterfaceAboutToBeReleased\0\0"
    "InterfaceAboutToBeDestroyed\0"
    "ShowingDesktopChanged\0WindowCreated\0"
    "dbus\0WindowRemove\0ActiveWindowChanged\0"
    "IsValid\0IsShowingDesktop\0SetShowingDesktop\0"
    "show\0ShowDesktop\0HideDesktop\0Windows\0"
    "ActiveWindow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PlasmaWindowManagerInterface[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      13,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   81,    4, 0x06 /* Public */,
       5,    0,   82,    4, 0x06 /* Public */,
       6,    1,   83,    4, 0x06 /* Public */,
       7,    1,   86,    4, 0x06 /* Public */,
       9,    1,   89,    4, 0x06 /* Public */,
      10,    0,   92,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   93,    4, 0x0a /* Public */,
      12,    0,   94,    4, 0x0a /* Public */,
      13,    1,   95,    4, 0x0a /* Public */,
      15,    0,   98,    4, 0x0a /* Public */,
      16,    0,   99,    4, 0x0a /* Public */,
      17,    0,  100,    4, 0x0a /* Public */,
      18,    0,  101,    4, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::QVariantList,
    QMetaType::UInt,

       0        // eod
};

void PlasmaWindowManagerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PlasmaWindowManagerInterface *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->InterfaceAboutToBeReleased(); break;
        case 1: _t->InterfaceAboutToBeDestroyed(); break;
        case 2: _t->ShowingDesktopChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->WindowCreated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->WindowRemove((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->ActiveWindowChanged(); break;
        case 6: { bool _r = _t->IsValid();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->IsShowingDesktop();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->SetShowingDesktop((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->ShowDesktop(); break;
        case 10: _t->HideDesktop(); break;
        case 11: { QList<QVariant> _r = _t->Windows();
            if (_a[0]) *reinterpret_cast< QList<QVariant>*>(_a[0]) = std::move(_r); }  break;
        case 12: { quint32 _r = _t->ActiveWindow();
            if (_a[0]) *reinterpret_cast< quint32*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PlasmaWindowManagerInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowManagerInterface::InterfaceAboutToBeReleased)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowManagerInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowManagerInterface::InterfaceAboutToBeDestroyed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowManagerInterface::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowManagerInterface::ShowingDesktopChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowManagerInterface::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowManagerInterface::WindowCreated)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowManagerInterface::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowManagerInterface::WindowRemove)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowManagerInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowManagerInterface::ActiveWindowChanged)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject PlasmaWindowManagerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_meta_stringdata_PlasmaWindowManagerInterface.data,
    qt_meta_data_PlasmaWindowManagerInterface,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PlasmaWindowManagerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaWindowManagerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PlasmaWindowManagerInterface.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PlasmaWindowManagerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void PlasmaWindowManagerInterface::InterfaceAboutToBeReleased()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlasmaWindowManagerInterface::InterfaceAboutToBeDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlasmaWindowManagerInterface::ShowingDesktopChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void PlasmaWindowManagerInterface::WindowCreated(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void PlasmaWindowManagerInterface::WindowRemove(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void PlasmaWindowManagerInterface::ActiveWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
