/****************************************************************************
** Meta object code from reading C++ file 'wlidle_interface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../wlidle_interface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wlidle_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_WlIdleInterface_t {
    QByteArrayData data[13];
    char stringdata0[146];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_WlIdleInterface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_WlIdleInterface_t qt_meta_stringdata_WlIdleInterface = {
    {
QT_MOC_LITERAL(0, 0, 15), // "WlIdleInterface"
QT_MOC_LITERAL(1, 16, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 32, 29), // "org.deepin.dde.KWayland1.Idle"
QT_MOC_LITERAL(3, 62, 11), // "IdleTimeout"
QT_MOC_LITERAL(4, 74, 0), // ""
QT_MOC_LITERAL(5, 75, 4), // "idle"
QT_MOC_LITERAL(6, 80, 14), // "SetIdleTimeout"
QT_MOC_LITERAL(7, 95, 4), // "time"
QT_MOC_LITERAL(8, 100, 7), // "setData"
QT_MOC_LITERAL(9, 108, 5), // "Seat*"
QT_MOC_LITERAL(10, 114, 4), // "seat"
QT_MOC_LITERAL(11, 119, 5), // "Idle*"
QT_MOC_LITERAL(12, 125, 20) // "simulateUserActivity"

    },
    "WlIdleInterface\0D-Bus Interface\0"
    "org.deepin.dde.KWayland1.Idle\0IdleTimeout\0"
    "\0idle\0SetIdleTimeout\0time\0setData\0"
    "Seat*\0seat\0Idle*\0simulateUserActivity"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_WlIdleInterface[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       4,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,   36,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   39,    4, 0x0a /* Public */,
       8,    2,   42,    4, 0x0a /* Public */,
      12,    0,   47,    4, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    5,

 // slots: parameters
    QMetaType::Void, QMetaType::UInt,    7,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 11,   10,    5,
    QMetaType::Void,

       0        // eod
};

void WlIdleInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<WlIdleInterface *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->IdleTimeout((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->SetIdleTimeout((*reinterpret_cast< quint32(*)>(_a[1]))); break;
        case 2: _t->setData((*reinterpret_cast< Seat*(*)>(_a[1])),(*reinterpret_cast< Idle*(*)>(_a[2]))); break;
        case 3: _t->simulateUserActivity(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Idle* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (WlIdleInterface::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WlIdleInterface::IdleTimeout)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject WlIdleInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_meta_stringdata_WlIdleInterface.data,
    qt_meta_data_WlIdleInterface,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *WlIdleInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WlIdleInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_WlIdleInterface.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int WlIdleInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void WlIdleInterface::IdleTimeout(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
