/****************************************************************************
** Meta object code from reading C++ file 'plasma_window_interface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../plasma_window_interface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasma_window_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PlasmaWindowInterface_t {
    QByteArrayData data[84];
    char stringdata0[1318];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PlasmaWindowInterface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PlasmaWindowInterface_t qt_meta_stringdata_PlasmaWindowInterface = {
    {
QT_MOC_LITERAL(0, 0, 21), // "PlasmaWindowInterface"
QT_MOC_LITERAL(1, 22, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 38, 37), // "org.deepin.dde.KWayland1.Plas..."
QT_MOC_LITERAL(3, 76, 13), // "ActiveChanged"
QT_MOC_LITERAL(4, 90, 0), // ""
QT_MOC_LITERAL(5, 91, 12), // "AppIdChanged"
QT_MOC_LITERAL(6, 104, 16), // "CloseableChanged"
QT_MOC_LITERAL(7, 121, 23), // "DemandsAttentionChanged"
QT_MOC_LITERAL(8, 145, 21), // "FullscreenableChanged"
QT_MOC_LITERAL(9, 167, 17), // "FullscreenChanged"
QT_MOC_LITERAL(10, 185, 15), // "GeometryChanged"
QT_MOC_LITERAL(11, 201, 11), // "IconChanged"
QT_MOC_LITERAL(12, 213, 16), // "KeepAboveChanged"
QT_MOC_LITERAL(13, 230, 16), // "KeepBelowChanged"
QT_MOC_LITERAL(14, 247, 19), // "MaximizeableChanged"
QT_MOC_LITERAL(15, 267, 16), // "MaximizedChanged"
QT_MOC_LITERAL(16, 284, 19), // "MinimizeableChanged"
QT_MOC_LITERAL(17, 304, 16), // "MinimizedChanged"
QT_MOC_LITERAL(18, 321, 14), // "MovableChanged"
QT_MOC_LITERAL(19, 336, 20), // "OnAllDesktopsChanged"
QT_MOC_LITERAL(20, 357, 19), // "ParentWindowChanged"
QT_MOC_LITERAL(21, 377, 27), // "PlasmaVirtualDesktopEntered"
QT_MOC_LITERAL(22, 405, 2), // "id"
QT_MOC_LITERAL(23, 408, 24), // "PlasmaVirtualDesktopLeft"
QT_MOC_LITERAL(24, 433, 16), // "ResizableChanged"
QT_MOC_LITERAL(25, 450, 16), // "ShadeableChanged"
QT_MOC_LITERAL(26, 467, 13), // "ShadedChanged"
QT_MOC_LITERAL(27, 481, 19), // "SkipSwitcherChanged"
QT_MOC_LITERAL(28, 501, 18), // "SkipTaskbarChanged"
QT_MOC_LITERAL(29, 520, 12), // "TitleChanged"
QT_MOC_LITERAL(30, 533, 8), // "Unmapped"
QT_MOC_LITERAL(31, 542, 31), // "VirtualDesktopChangeableChanged"
QT_MOC_LITERAL(32, 574, 21), // "VirtualDesktopChanged"
QT_MOC_LITERAL(33, 596, 5), // "AppId"
QT_MOC_LITERAL(34, 602, 7), // "Destroy"
QT_MOC_LITERAL(35, 610, 8), // "Geometry"
QT_MOC_LITERAL(36, 619, 4), // "Icon"
QT_MOC_LITERAL(37, 624, 10), // "InternalId"
QT_MOC_LITERAL(38, 635, 8), // "IsActive"
QT_MOC_LITERAL(39, 644, 11), // "IsCloseable"
QT_MOC_LITERAL(40, 656, 20), // "IsDemandingAttention"
QT_MOC_LITERAL(41, 677, 12), // "IsFullscreen"
QT_MOC_LITERAL(42, 690, 16), // "IsFullscreenable"
QT_MOC_LITERAL(43, 707, 11), // "IsKeepAbove"
QT_MOC_LITERAL(44, 719, 11), // "IsKeepBelow"
QT_MOC_LITERAL(45, 731, 14), // "IsMaximizeable"
QT_MOC_LITERAL(46, 746, 11), // "IsMaximized"
QT_MOC_LITERAL(47, 758, 14), // "IsMinimizeable"
QT_MOC_LITERAL(48, 773, 11), // "IsMinimized"
QT_MOC_LITERAL(49, 785, 9), // "IsMovable"
QT_MOC_LITERAL(50, 795, 15), // "IsOnAllDesktops"
QT_MOC_LITERAL(51, 811, 11), // "IsResizable"
QT_MOC_LITERAL(52, 823, 11), // "IsShadeable"
QT_MOC_LITERAL(53, 835, 8), // "IsShaded"
QT_MOC_LITERAL(54, 844, 7), // "IsValid"
QT_MOC_LITERAL(55, 852, 26), // "IsVirtualDesktopChangeable"
QT_MOC_LITERAL(56, 879, 3), // "Pid"
QT_MOC_LITERAL(57, 883, 21), // "PlasmaVirtualDesktops"
QT_MOC_LITERAL(58, 905, 7), // "Release"
QT_MOC_LITERAL(59, 913, 15), // "RequestActivate"
QT_MOC_LITERAL(60, 929, 12), // "RequestClose"
QT_MOC_LITERAL(61, 942, 29), // "RequestEnterNewVirtualDesktop"
QT_MOC_LITERAL(62, 972, 26), // "RequestEnterVirtualDesktop"
QT_MOC_LITERAL(63, 999, 26), // "RequestLeaveVirtualDesktop"
QT_MOC_LITERAL(64, 1026, 11), // "RequestMove"
QT_MOC_LITERAL(65, 1038, 13), // "RequestResize"
QT_MOC_LITERAL(66, 1052, 22), // "RequestToggleKeepAbove"
QT_MOC_LITERAL(67, 1075, 22), // "RequestToggleKeepBelow"
QT_MOC_LITERAL(68, 1098, 22), // "RequestToggleMaximized"
QT_MOC_LITERAL(69, 1121, 22), // "RequestToggleMinimized"
QT_MOC_LITERAL(70, 1144, 19), // "RequestToggleShaded"
QT_MOC_LITERAL(71, 1164, 21), // "RequestVirtualDesktop"
QT_MOC_LITERAL(72, 1186, 7), // "desktop"
QT_MOC_LITERAL(73, 1194, 20), // "SetMinimizedGeometry"
QT_MOC_LITERAL(74, 1215, 8), // "Surface*"
QT_MOC_LITERAL(75, 1224, 5), // "panel"
QT_MOC_LITERAL(76, 1230, 4), // "geom"
QT_MOC_LITERAL(77, 1235, 12), // "SkipSwitcher"
QT_MOC_LITERAL(78, 1248, 11), // "SkipTaskbar"
QT_MOC_LITERAL(79, 1260, 5), // "Title"
QT_MOC_LITERAL(80, 1266, 22), // "UnsetMinimizedGeometry"
QT_MOC_LITERAL(81, 1289, 14), // "VirtualDesktop"
QT_MOC_LITERAL(82, 1304, 8), // "WindowId"
QT_MOC_LITERAL(83, 1313, 4) // "uuid"

    },
    "PlasmaWindowInterface\0D-Bus Interface\0"
    "org.deepin.dde.KWayland1.PlasmaWindow\0"
    "ActiveChanged\0\0AppIdChanged\0"
    "CloseableChanged\0DemandsAttentionChanged\0"
    "FullscreenableChanged\0FullscreenChanged\0"
    "GeometryChanged\0IconChanged\0"
    "KeepAboveChanged\0KeepBelowChanged\0"
    "MaximizeableChanged\0MaximizedChanged\0"
    "MinimizeableChanged\0MinimizedChanged\0"
    "MovableChanged\0OnAllDesktopsChanged\0"
    "ParentWindowChanged\0PlasmaVirtualDesktopEntered\0"
    "id\0PlasmaVirtualDesktopLeft\0"
    "ResizableChanged\0ShadeableChanged\0"
    "ShadedChanged\0SkipSwitcherChanged\0"
    "SkipTaskbarChanged\0TitleChanged\0"
    "Unmapped\0VirtualDesktopChangeableChanged\0"
    "VirtualDesktopChanged\0AppId\0Destroy\0"
    "Geometry\0Icon\0InternalId\0IsActive\0"
    "IsCloseable\0IsDemandingAttention\0"
    "IsFullscreen\0IsFullscreenable\0IsKeepAbove\0"
    "IsKeepBelow\0IsMaximizeable\0IsMaximized\0"
    "IsMinimizeable\0IsMinimized\0IsMovable\0"
    "IsOnAllDesktops\0IsResizable\0IsShadeable\0"
    "IsShaded\0IsValid\0IsVirtualDesktopChangeable\0"
    "Pid\0PlasmaVirtualDesktops\0Release\0"
    "RequestActivate\0RequestClose\0"
    "RequestEnterNewVirtualDesktop\0"
    "RequestEnterVirtualDesktop\0"
    "RequestLeaveVirtualDesktop\0RequestMove\0"
    "RequestResize\0RequestToggleKeepAbove\0"
    "RequestToggleKeepBelow\0RequestToggleMaximized\0"
    "RequestToggleMinimized\0RequestToggleShaded\0"
    "RequestVirtualDesktop\0desktop\0"
    "SetMinimizedGeometry\0Surface*\0panel\0"
    "geom\0SkipSwitcher\0SkipTaskbar\0Title\0"
    "UnsetMinimizedGeometry\0VirtualDesktop\0"
    "WindowId\0uuid"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PlasmaWindowInterface[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      75,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      28,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,  391,    4, 0x06 /* Public */,
       5,    0,  392,    4, 0x06 /* Public */,
       6,    0,  393,    4, 0x06 /* Public */,
       7,    0,  394,    4, 0x06 /* Public */,
       8,    0,  395,    4, 0x06 /* Public */,
       9,    0,  396,    4, 0x06 /* Public */,
      10,    0,  397,    4, 0x06 /* Public */,
      11,    0,  398,    4, 0x06 /* Public */,
      12,    0,  399,    4, 0x06 /* Public */,
      13,    0,  400,    4, 0x06 /* Public */,
      14,    0,  401,    4, 0x06 /* Public */,
      15,    0,  402,    4, 0x06 /* Public */,
      16,    0,  403,    4, 0x06 /* Public */,
      17,    0,  404,    4, 0x06 /* Public */,
      18,    0,  405,    4, 0x06 /* Public */,
      19,    0,  406,    4, 0x06 /* Public */,
      20,    0,  407,    4, 0x06 /* Public */,
      21,    1,  408,    4, 0x06 /* Public */,
      23,    1,  411,    4, 0x06 /* Public */,
      24,    0,  414,    4, 0x06 /* Public */,
      25,    0,  415,    4, 0x06 /* Public */,
      26,    0,  416,    4, 0x06 /* Public */,
      27,    0,  417,    4, 0x06 /* Public */,
      28,    0,  418,    4, 0x06 /* Public */,
      29,    0,  419,    4, 0x06 /* Public */,
      30,    0,  420,    4, 0x06 /* Public */,
      31,    0,  421,    4, 0x06 /* Public */,
      32,    0,  422,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      33,    0,  423,    4, 0x0a /* Public */,
      34,    0,  424,    4, 0x0a /* Public */,
      35,    0,  425,    4, 0x0a /* Public */,
      36,    0,  426,    4, 0x0a /* Public */,
      37,    0,  427,    4, 0x0a /* Public */,
      38,    0,  428,    4, 0x0a /* Public */,
      39,    0,  429,    4, 0x0a /* Public */,
      40,    0,  430,    4, 0x0a /* Public */,
      41,    0,  431,    4, 0x0a /* Public */,
      42,    0,  432,    4, 0x0a /* Public */,
      43,    0,  433,    4, 0x0a /* Public */,
      44,    0,  434,    4, 0x0a /* Public */,
      45,    0,  435,    4, 0x0a /* Public */,
      46,    0,  436,    4, 0x0a /* Public */,
      47,    0,  437,    4, 0x0a /* Public */,
      48,    0,  438,    4, 0x0a /* Public */,
      49,    0,  439,    4, 0x0a /* Public */,
      50,    0,  440,    4, 0x0a /* Public */,
      51,    0,  441,    4, 0x0a /* Public */,
      52,    0,  442,    4, 0x0a /* Public */,
      53,    0,  443,    4, 0x0a /* Public */,
      54,    0,  444,    4, 0x0a /* Public */,
      55,    0,  445,    4, 0x0a /* Public */,
      56,    0,  446,    4, 0x0a /* Public */,
      57,    0,  447,    4, 0x0a /* Public */,
      58,    0,  448,    4, 0x0a /* Public */,
      59,    0,  449,    4, 0x0a /* Public */,
      60,    0,  450,    4, 0x0a /* Public */,
      61,    0,  451,    4, 0x0a /* Public */,
      62,    1,  452,    4, 0x0a /* Public */,
      63,    1,  455,    4, 0x0a /* Public */,
      64,    0,  458,    4, 0x0a /* Public */,
      65,    0,  459,    4, 0x0a /* Public */,
      66,    0,  460,    4, 0x0a /* Public */,
      67,    0,  461,    4, 0x0a /* Public */,
      68,    0,  462,    4, 0x0a /* Public */,
      69,    0,  463,    4, 0x0a /* Public */,
      70,    0,  464,    4, 0x0a /* Public */,
      71,    1,  465,    4, 0x0a /* Public */,
      73,    2,  468,    4, 0x0a /* Public */,
      77,    0,  473,    4, 0x0a /* Public */,
      78,    0,  474,    4, 0x0a /* Public */,
      79,    0,  475,    4, 0x0a /* Public */,
      80,    1,  476,    4, 0x0a /* Public */,
      81,    0,  479,    4, 0x0a /* Public */,
      82,    0,  480,    4, 0x0a /* Public */,
      83,    0,  481,    4, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::QString,
    QMetaType::Void,
    QMetaType::QRect,
    QMetaType::QString,
    QMetaType::UInt,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::UInt,
    QMetaType::QStringList,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,   72,
    QMetaType::Void, 0x80000000 | 74, QMetaType::QRect,   75,   76,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::QString,
    QMetaType::Void, 0x80000000 | 74,   75,
    QMetaType::UInt,
    QMetaType::UInt,
    QMetaType::QByteArray,

       0        // eod
};

void PlasmaWindowInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PlasmaWindowInterface *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->ActiveChanged(); break;
        case 1: _t->AppIdChanged(); break;
        case 2: _t->CloseableChanged(); break;
        case 3: _t->DemandsAttentionChanged(); break;
        case 4: _t->FullscreenableChanged(); break;
        case 5: _t->FullscreenChanged(); break;
        case 6: _t->GeometryChanged(); break;
        case 7: _t->IconChanged(); break;
        case 8: _t->KeepAboveChanged(); break;
        case 9: _t->KeepBelowChanged(); break;
        case 10: _t->MaximizeableChanged(); break;
        case 11: _t->MaximizedChanged(); break;
        case 12: _t->MinimizeableChanged(); break;
        case 13: _t->MinimizedChanged(); break;
        case 14: _t->MovableChanged(); break;
        case 15: _t->OnAllDesktopsChanged(); break;
        case 16: _t->ParentWindowChanged(); break;
        case 17: _t->PlasmaVirtualDesktopEntered((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->PlasmaVirtualDesktopLeft((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->ResizableChanged(); break;
        case 20: _t->ShadeableChanged(); break;
        case 21: _t->ShadedChanged(); break;
        case 22: _t->SkipSwitcherChanged(); break;
        case 23: _t->SkipTaskbarChanged(); break;
        case 24: _t->TitleChanged(); break;
        case 25: _t->Unmapped(); break;
        case 26: _t->VirtualDesktopChangeableChanged(); break;
        case 27: _t->VirtualDesktopChanged(); break;
        case 28: { QString _r = _t->AppId();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->Destroy(); break;
        case 30: { QRect _r = _t->Geometry();
            if (_a[0]) *reinterpret_cast< QRect*>(_a[0]) = std::move(_r); }  break;
        case 31: { QString _r = _t->Icon();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 32: { quint32 _r = _t->InternalId();
            if (_a[0]) *reinterpret_cast< quint32*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->IsActive();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->IsCloseable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->IsDemandingAttention();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->IsFullscreen();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->IsFullscreenable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->IsKeepAbove();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { bool _r = _t->IsKeepBelow();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->IsMaximizeable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->IsMaximized();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { bool _r = _t->IsMinimizeable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 43: { bool _r = _t->IsMinimized();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->IsMovable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 45: { bool _r = _t->IsOnAllDesktops();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 46: { bool _r = _t->IsResizable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 47: { bool _r = _t->IsShadeable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 48: { bool _r = _t->IsShaded();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 49: { bool _r = _t->IsValid();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 50: { bool _r = _t->IsVirtualDesktopChangeable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 51: { quint32 _r = _t->Pid();
            if (_a[0]) *reinterpret_cast< quint32*>(_a[0]) = std::move(_r); }  break;
        case 52: { QStringList _r = _t->PlasmaVirtualDesktops();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->Release(); break;
        case 54: _t->RequestActivate(); break;
        case 55: _t->RequestClose(); break;
        case 56: _t->RequestEnterNewVirtualDesktop(); break;
        case 57: _t->RequestEnterVirtualDesktop((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 58: _t->RequestLeaveVirtualDesktop((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 59: _t->RequestMove(); break;
        case 60: _t->RequestResize(); break;
        case 61: _t->RequestToggleKeepAbove(); break;
        case 62: _t->RequestToggleKeepBelow(); break;
        case 63: _t->RequestToggleMaximized(); break;
        case 64: _t->RequestToggleMinimized(); break;
        case 65: _t->RequestToggleShaded(); break;
        case 66: _t->RequestVirtualDesktop((*reinterpret_cast< quint32(*)>(_a[1]))); break;
        case 67: _t->SetMinimizedGeometry((*reinterpret_cast< Surface*(*)>(_a[1])),(*reinterpret_cast< const QRect(*)>(_a[2]))); break;
        case 68: { bool _r = _t->SkipSwitcher();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 69: { bool _r = _t->SkipTaskbar();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 70: { QString _r = _t->Title();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 71: _t->UnsetMinimizedGeometry((*reinterpret_cast< Surface*(*)>(_a[1]))); break;
        case 72: { quint32 _r = _t->VirtualDesktop();
            if (_a[0]) *reinterpret_cast< quint32*>(_a[0]) = std::move(_r); }  break;
        case 73: { quint32 _r = _t->WindowId();
            if (_a[0]) *reinterpret_cast< quint32*>(_a[0]) = std::move(_r); }  break;
        case 74: { QByteArray _r = _t->uuid();
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::ActiveChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::AppIdChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::CloseableChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::DemandsAttentionChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::FullscreenableChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::FullscreenChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::GeometryChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::IconChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::KeepAboveChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::KeepBelowChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::MaximizeableChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::MaximizedChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::MinimizeableChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::MinimizedChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::MovableChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::OnAllDesktopsChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::ParentWindowChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::PlasmaVirtualDesktopEntered)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::PlasmaVirtualDesktopLeft)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::ResizableChanged)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::ShadeableChanged)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::ShadedChanged)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::SkipSwitcherChanged)) {
                *result = 22;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::SkipTaskbarChanged)) {
                *result = 23;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::TitleChanged)) {
                *result = 24;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::Unmapped)) {
                *result = 25;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::VirtualDesktopChangeableChanged)) {
                *result = 26;
                return;
            }
        }
        {
            using _t = void (PlasmaWindowInterface::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlasmaWindowInterface::VirtualDesktopChanged)) {
                *result = 27;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject PlasmaWindowInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_meta_stringdata_PlasmaWindowInterface.data,
    qt_meta_data_PlasmaWindowInterface,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PlasmaWindowInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlasmaWindowInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PlasmaWindowInterface.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PlasmaWindowInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 75)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 75;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 75)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 75;
    }
    return _id;
}

// SIGNAL 0
void PlasmaWindowInterface::ActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlasmaWindowInterface::AppIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlasmaWindowInterface::CloseableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PlasmaWindowInterface::DemandsAttentionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PlasmaWindowInterface::FullscreenableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PlasmaWindowInterface::FullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PlasmaWindowInterface::GeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PlasmaWindowInterface::IconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PlasmaWindowInterface::KeepAboveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PlasmaWindowInterface::KeepBelowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PlasmaWindowInterface::MaximizeableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void PlasmaWindowInterface::MaximizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void PlasmaWindowInterface::MinimizeableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void PlasmaWindowInterface::MinimizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void PlasmaWindowInterface::MovableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void PlasmaWindowInterface::OnAllDesktopsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void PlasmaWindowInterface::ParentWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void PlasmaWindowInterface::PlasmaVirtualDesktopEntered(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void PlasmaWindowInterface::PlasmaVirtualDesktopLeft(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void PlasmaWindowInterface::ResizableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void PlasmaWindowInterface::ShadeableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void PlasmaWindowInterface::ShadedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void PlasmaWindowInterface::SkipSwitcherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void PlasmaWindowInterface::SkipTaskbarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void PlasmaWindowInterface::TitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void PlasmaWindowInterface::Unmapped()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void PlasmaWindowInterface::VirtualDesktopChangeableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void PlasmaWindowInterface::VirtualDesktopChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
