/****************************************************************************
** Meta object code from reading C++ file 'wloutput_interface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../wloutput_interface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wloutput_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_wloutput_interface_t {
    QByteArrayData data[29];
    char stringdata0[323];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_wloutput_interface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_wloutput_interface_t qt_meta_stringdata_wloutput_interface = {
    {
QT_MOC_LITERAL(0, 0, 18), // "wloutput_interface"
QT_MOC_LITERAL(1, 19, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 35, 31), // "org.deepin.dde.KWayland1.Output"
QT_MOC_LITERAL(3, 67, 11), // "OutputAdded"
QT_MOC_LITERAL(4, 79, 0), // ""
QT_MOC_LITERAL(5, 80, 6), // "output"
QT_MOC_LITERAL(6, 87, 13), // "OutputRemoved"
QT_MOC_LITERAL(7, 101, 13), // "OutputChanged"
QT_MOC_LITERAL(8, 115, 20), // "PrimaryOutputChanged"
QT_MOC_LITERAL(9, 136, 10), // "outputName"
QT_MOC_LITERAL(10, 147, 11), // "ButtonPress"
QT_MOC_LITERAL(11, 159, 6), // "button"
QT_MOC_LITERAL(12, 166, 1), // "x"
QT_MOC_LITERAL(13, 168, 1), // "y"
QT_MOC_LITERAL(14, 170, 13), // "ButtonRelease"
QT_MOC_LITERAL(15, 184, 10), // "CursorMove"
QT_MOC_LITERAL(16, 195, 11), // "AxisChanged"
QT_MOC_LITERAL(17, 207, 11), // "orientation"
QT_MOC_LITERAL(18, 219, 5), // "delta"
QT_MOC_LITERAL(19, 225, 10), // "ListOutput"
QT_MOC_LITERAL(20, 236, 9), // "GetOutput"
QT_MOC_LITERAL(21, 246, 4), // "uuid"
QT_MOC_LITERAL(22, 251, 10), // "setPrimary"
QT_MOC_LITERAL(23, 262, 5), // "Apply"
QT_MOC_LITERAL(24, 268, 7), // "outputs"
QT_MOC_LITERAL(25, 276, 13), // "WlSimulateKey"
QT_MOC_LITERAL(26, 290, 7), // "keycode"
QT_MOC_LITERAL(27, 298, 13), // "setBrightness"
QT_MOC_LITERAL(28, 312, 10) // "brightness"

    },
    "wloutput_interface\0D-Bus Interface\0"
    "org.deepin.dde.KWayland1.Output\0"
    "OutputAdded\0\0output\0OutputRemoved\0"
    "OutputChanged\0PrimaryOutputChanged\0"
    "outputName\0ButtonPress\0button\0x\0y\0"
    "ButtonRelease\0CursorMove\0AxisChanged\0"
    "orientation\0delta\0ListOutput\0GetOutput\0"
    "uuid\0setPrimary\0Apply\0outputs\0"
    "WlSimulateKey\0keycode\0setBrightness\0"
    "brightness"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_wloutput_interface[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      14,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,   86,    4, 0x06 /* Public */,
       6,    1,   89,    4, 0x06 /* Public */,
       7,    1,   92,    4, 0x06 /* Public */,
       8,    1,   95,    4, 0x06 /* Public */,
      10,    3,   98,    4, 0x06 /* Public */,
      14,    3,  105,    4, 0x06 /* Public */,
      15,    2,  112,    4, 0x06 /* Public */,
      16,    2,  117,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    0,  122,    4, 0x0a /* Public */,
      20,    1,  123,    4, 0x0a /* Public */,
      22,    1,  126,    4, 0x0a /* Public */,
      23,    1,  129,    4, 0x0a /* Public */,
      25,    1,  132,    4, 0x0a /* Public */,
      27,    2,  135,    4, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt, QMetaType::UInt,   11,   12,   13,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt, QMetaType::UInt,   11,   12,   13,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt,   12,   13,
    QMetaType::Void, QMetaType::Int, QMetaType::QReal,   17,   18,

 // slots: parameters
    QMetaType::QString,
    QMetaType::QString, QMetaType::QString,   21,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   21,   28,

       0        // eod
};

void wloutput_interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<wloutput_interface *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->OutputAdded((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->OutputRemoved((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->OutputChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: _t->PrimaryOutputChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->ButtonPress((*reinterpret_cast< quint32(*)>(_a[1])),(*reinterpret_cast< quint32(*)>(_a[2])),(*reinterpret_cast< quint32(*)>(_a[3]))); break;
        case 5: _t->ButtonRelease((*reinterpret_cast< quint32(*)>(_a[1])),(*reinterpret_cast< quint32(*)>(_a[2])),(*reinterpret_cast< quint32(*)>(_a[3]))); break;
        case 6: _t->CursorMove((*reinterpret_cast< quint32(*)>(_a[1])),(*reinterpret_cast< quint32(*)>(_a[2]))); break;
        case 7: _t->AxisChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 8: { QString _r = _t->ListOutput();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->GetOutput((*reinterpret_cast< QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setPrimary((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->Apply((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 12: _t->WlSimulateKey((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->setBrightness((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< const int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (wloutput_interface::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&wloutput_interface::OutputAdded)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (wloutput_interface::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&wloutput_interface::OutputRemoved)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (wloutput_interface::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&wloutput_interface::OutputChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (wloutput_interface::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&wloutput_interface::PrimaryOutputChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (wloutput_interface::*)(quint32 , quint32 , quint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&wloutput_interface::ButtonPress)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (wloutput_interface::*)(quint32 , quint32 , quint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&wloutput_interface::ButtonRelease)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (wloutput_interface::*)(quint32 , quint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&wloutput_interface::CursorMove)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (wloutput_interface::*)(int , qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&wloutput_interface::AxisChanged)) {
                *result = 7;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject wloutput_interface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_meta_stringdata_wloutput_interface.data,
    qt_meta_data_wloutput_interface,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *wloutput_interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *wloutput_interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_wloutput_interface.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int wloutput_interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void wloutput_interface::OutputAdded(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void wloutput_interface::OutputRemoved(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void wloutput_interface::OutputChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void wloutput_interface::PrimaryOutputChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void wloutput_interface::ButtonPress(quint32 _t1, quint32 _t2, quint32 _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void wloutput_interface::ButtonRelease(quint32 _t1, quint32 _t2, quint32 _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void wloutput_interface::CursorMove(quint32 _t1, quint32 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void wloutput_interface::AxisChanged(int _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
